"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.highlightWithPrism = exports.githubReadmeUrl = exports.npmPackageUrl = exports.getMarkdownFromUrl = exports.prettifyTable = exports.isMarkdownTable = exports.toMarkdown = exports.toAst = void 0;
const unified_1 = __importDefault(require("unified"));
const remark_parse_1 = __importDefault(require("remark-parse"));
const remark_stringify_1 = __importDefault(require("remark-stringify"));
const marktable_1 = __importDefault(require("marktable"));
const cli_table_1 = __importDefault(require("cli-table"));
const axios_1 = __importDefault(require("axios"));
const prism_cli_1 = __importDefault(require("prism-cli"));
const toAst = (markdown) => {
    return unified_1.default().use(remark_parse_1.default).parse(markdown);
};
exports.toAst = toAst;
const toMarkdown = (node) => {
    return unified_1.default().use(remark_stringify_1.default).stringify(node);
};
exports.toMarkdown = toMarkdown;
const isMarkdownTable = (text) => {
    // https://github.com/erikvullings/slimdown-js/blob/master/src/slimdown.ts 125
    return /(\|[^\n]+\|\r?\n)((?:\|:?[-]+:?)+\|)(\n(?:\|[^\n]+\|\r?\n?)*)?/g.test(text);
};
exports.isMarkdownTable = isMarkdownTable;
const prettifyTable = (mdt) => {
    let parsedTable = marktable_1.default(mdt);
    let tableArray = parsedTable
        .trim()
        .split('\n')
        .map((s) => s
        .split('|')
        .filter((c) => !c.includes('-'))
        .filter((d) => /\s+/.test(d)))
        .filter((e) => e.length > 1);
    const table = new cli_table_1.default({
        head: tableArray.shift(),
        chars: {
            top: '═',
            'top-mid': '╤',
            'top-left': '╔',
            'top-right': '╗',
            bottom: '═',
            'bottom-mid': '╧',
            'bottom-left': '╚',
            'bottom-right': '╝',
            left: '║',
            'left-mid': '╟',
            mid: '─',
            'mid-mid': '┼',
            right: '║',
            'right-mid': '╢',
            middle: '│',
        },
    });
    tableArray.forEach((e) => {
        table.push(e);
    });
    return table.toString();
};
exports.prettifyTable = prettifyTable;
const getMarkdownFromUrl = (url) => __awaiter(void 0, void 0, void 0, function* () {
    const requestData = yield axios_1.default.get(url);
    return requestData.data;
});
exports.getMarkdownFromUrl = getMarkdownFromUrl;
const npmPackageUrl = (packageName) => {
    const NPM_REGISTRY = 'https://registry.npmjs.com/';
    return NPM_REGISTRY + packageName;
};
exports.npmPackageUrl = npmPackageUrl;
const githubReadmeUrl = (repoName) => {
    const GITHUB_URL = `https://api.github.com/repos/${repoName}/readme`;
    return GITHUB_URL;
};
exports.githubReadmeUrl = githubReadmeUrl;
const highlightWithPrism = (code, language) => {
    return prism_cli_1.default(code, language, {
        colors: {
            comment: '\x1B[38;2;107;114;128m',
            prolog: '\x1B[38;2;107;114;128m',
            doctype: '\x1B[38;2;107;114;128m',
            cdata: '\x1B[38;2;107;114;128m',
            punctuation: '\x1B[38;2;153;153;153m',
            property: '\x1B[38;2;153;0;85m',
            tag: '\x1B[38;2;153;0;85m',
            boolean: '\x1B[38;2;153;0;85m',
            number: '\x1B[38;2;153;0;85m',
            constant: '\x1B[38;2;153;0;85m',
            symbol: '\x1B[38;2;153;0;85m',
            deleted: '\x1B[38;2;153;0;85m',
            selector: '\x1B[38;2;16;185;129m',
            'attr-name': '\x1B[38;2;16;185;129m',
            string: '\x1B[38;2;16;185;129m',
            char: '\x1B[38;2;16;185;129m',
            builtin: '\x1B[38;2;16;185;129m',
            inserted: '\x1B[38;2;16;185;129m',
            operator: '\x1B[38;2;154;110;58m',
            entity: '\x1B[38;2;154;110;58m',
            url: '\x1B[38;2;154;110;58m',
            atrule: '\x1B[38;2;96;165;250m',
            'attr-value': '\x1B[38;2;96;165;250m',
            keyword: '\x1B[38;2;96;165;250m',
            function: '\x1B[38;2;221;74;104m',
            'class-name': '\x1B[38;2;221;74;104m',
            regex: '\x1B[38;2;238;153;0m',
            important: '\x1B[38;2;238;153;0m',
            variable: '\x1B[38;2;238;153;0m',
        },
    });
};
exports.highlightWithPrism = highlightWithPrism;
